@@ -196,7 +196,7 @@ setReplaceMethod("seqinfo", "GAlignmentPairs",
     {
         if (!is(value, "Seqinfo"))
             stop("the supplied 'seqinfo' must be a Seqinfo object")
-        dangling_seqlevels <- GenomicRanges:::getDanglingSeqlevels(x,
+        dangling_seqlevels <- GenomeInfoDb:::getDanglingSeqlevels(x,
                                   new2old=new2old, force=force,
                                   seqlevels(value))
         if (length(dangling_seqlevels) != 0L) {
@@ -262,7 +262,7 @@ setReplaceMethod("seqinfo", "GAlignmentPairs",
     }
     if (length(x_isProperPair) != length(x))
         return("'x@isProperPair' and 'x' must have the same length")
-    if (IRanges:::anyMissing(x_isProperPair))
+    if (S4Vectors:::anyMissing(x_isProperPair))
         return("'x@isProperPair' cannot contain NAs")
     NULL
 }
@@ -298,21 +298,20 @@ GAlignmentPairs <- function(first, last, isProperPair, names=NULL)
 ### Vector methods.
 ###
 
-setMethod(IRanges:::extractROWS, "GAlignmentPairs",
+setMethod("extractROWS", "GAlignmentPairs",
     function(x, i)
     {
-        if (missing(i) || !is(i, "Ranges"))
-            i <- IRanges:::normalizeSingleBracketSubscript(i, x)
-        ans_names <- IRanges:::extractROWS(names(x), i)
-        ans_first <- IRanges:::extractROWS(first(x), i)
-        ans_last <- IRanges:::extractROWS(last(x), i)
-        ans_isProperPair <- IRanges:::extractROWS(isProperPair(x), i)
-        ans_mcols <- IRanges:::extractROWS(mcols(x), i)
-        initialize(x, NAMES=ans_names,
+        i <- normalizeSingleBracketSubscript(i, x, as.NSBS=TRUE)
+        ans_NAMES <- extractROWS(x@NAMES, i)
+        ans_first <- extractROWS(x@first, i)
+        ans_last <- extractROWS(x@last, i)
+        ans_isProperPair <- extractROWS(x@isProperPair, i)
+        ans_elementMetadata <- extractROWS(x@elementMetadata, i)
+        initialize(x, NAMES=ans_NAMES,
                       first=ans_first,
                       last=ans_last,
                       isProperPair=ans_isProperPair,
-                      elementMetadata=ans_mcols)
+                      elementMetadata=ans_elementMetadata)
     }
 )
 
@@ -336,7 +335,7 @@ setMethod("[[", "GAlignmentPairs",
     {
         if (missing(i) || !missing(j) || length(list(...)) > 0L)
             stop("invalid subsetting")
-        i <- IRanges:::normalizeDoubleBracketSubscript(i, x)
+        i <- normalizeDoubleBracketSubscript(i, x)
         .GAlignmentPairs.getElement(x, i)
     }
 )
@@ -351,7 +350,7 @@ setMethod("unlist", "GAlignmentPairs",
         x_first <- x@first
         x_last <- x@last
         collate_subscript <-
-            IRanges:::make_XYZxyz_to_XxYyZz_subscript(length(x))
+            S4Vectors:::make_XYZxyz_to_XxYyZz_subscript(length(x))
         ans <- c(x_first, x_last)[collate_subscript]
         if (use.names)
             names(ans) <- rep(names(x), each=2L)
@@ -398,7 +397,7 @@ setMethod("grglist", "GAlignmentPairs",
         x_last <- invertRleStrand(x@last)
         ## Not the same as doing 'unlist(x, use.names=FALSE)'.
         collate_subscript <-
-            IRanges:::make_XYZxyz_to_XxYyZz_subscript(length(x))
+            S4Vectors:::make_XYZxyz_to_XxYyZz_subscript(length(x))
         x_unlisted <- c(x_first, x_last)[collate_subscript]
         grl <- grglist(x_unlisted,
                        order.as.in.query=TRUE,
@@ -466,7 +465,7 @@ fillJunctionGaps <- function(x)
     offsets <- end(x@partitioning)
     if (length(x) != 0L) 
         offsets <- c(0L, offsets[-length(offsets)])
-    idx <- IRanges:::fancy_mseq(query.breaks, offsets)
+    idx <- S4Vectors:::fancy_mseq(query.breaks, offsets)
     half1_partitioning <- PartitioningByEnd(cumsum(query.breaks))
     half1 <- relist(x@unlistData[idx], half1_partitioning)
     half1 <- range(half1)@unlistData
@@ -474,7 +473,7 @@ fillJunctionGaps <- function(x)
     half2_partitioning <- PartitioningByEnd(cumsum(half2_eltlens))
     half2 <- relist(x@unlistData[-idx], half2_partitioning)
     half2 <- range(half2)@unlistData
-    collate_subscript <- IRanges:::make_XYZxyz_to_XxYyZz_subscript(length(x))
+    collate_subscript <- S4Vectors:::make_XYZxyz_to_XxYyZz_subscript(length(x))
     ans_unlistData <- c(half1, half2)[collate_subscript]
     ans_partitioning <- PartitioningByEnd(2L * seq_along(x),
                                           names=names(x))
@@ -509,19 +508,19 @@ fillJunctionGaps <- function(x)
 }
 
 showGAlignmentPairs <- function(x, margin="",
-                                   with.classinfo=FALSE,
-                                   print.seqlengths=FALSE)
+                                   print.classinfo=FALSE,
+                                   print.seqinfo=FALSE)
 {
     lx <- length(x)
     nc <- ncol(mcols(x))
-    cat(class(x), " with ",
+    cat(class(x), " object with ",
         lx, " alignment ", ifelse(lx == 1L, "pair", "pairs"),
         " and ",
         nc, " metadata ", ifelse(nc == 1L, "column", "columns"),
         ":\n", sep="")
-    out <- IRanges:::makePrettyMatrixForCompactPrinting(x,
+    out <- S4Vectors:::makePrettyMatrixForCompactPrinting(x,
                .makeNakedMatFromGAlignmentPairs)
-    if (with.classinfo) {
+    if (print.classinfo) {
         .PAIR_COL2CLASS <- c(
             seqnames="Rle",
             strand="Rle"
@@ -535,7 +534,7 @@ showGAlignmentPairs <- function(x, margin="",
                         "--",
                         .HALVES_COL2CLASS)
         classinfo <-
-            GenomicRanges:::makeClassinfoRowForCompactPrinting(x, .COL2CLASS)
+            S4Vectors:::makeClassinfoRowForCompactPrinting(x, .COL2CLASS)
         ## A sanity check, but this should never happen!
         stopifnot(identical(colnames(classinfo), colnames(out)))
         out <- rbind(classinfo, out)
@@ -546,16 +545,16 @@ showGAlignmentPairs <- function(x, margin="",
     ## limit that would typically be reached when 'showHeadLines' global
     ## option is set to Inf.
     print(out, quote=FALSE, right=TRUE, max=length(out))
-    if (print.seqlengths) {
-        cat(margin, "---\n", sep="")
-        GenomicRanges:::showSeqlengths(x, margin=margin)
+    if (print.seqinfo) {
+        cat(margin, "-------\n", sep="")
+        cat(margin, "seqinfo: ", summary(seqinfo(x)), "\n", sep="")
     }
 }
 
 setMethod("show", "GAlignmentPairs",
     function(object)
-        showGAlignmentPairs(object,
-                            with.classinfo=TRUE, print.seqlengths=TRUE)
+        showGAlignmentPairs(object, margin="  ",
+                            print.classinfo=TRUE, print.seqinfo=TRUE)
 )
 
 
@@ -673,42 +672,3 @@ setMethod("c", "GAlignmentPairs",
     }
 )
 
-
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Old stuff (deprecated & defunct)
-###
-
-.GappedAlignmentPairs_warning_msg <- function()
-{
-    msg <- c("  The GappedAlignmentPairs class, the GappedAlignmentPairs()",
-             "constructor, and the readGappedAlignmentPairs() function, have",
-             "been renamed: GAlignmentPairs, GAlignmentPairs(), and",
-             "readGAlignmentPairs(), respectively. The old names are now",
-             "defunct. Please use the new names instead.")
-    paste0(msg, collapse="\n  ")
-}
-
-setClass("GappedAlignmentPairs", contains="GAlignmentPairs")
-
-setValidity("GappedAlignmentPairs",
-    function(object) .Defunct(msg=.GappedAlignmentPairs_warning_msg())
-)
-
-setMethod("show", "GappedAlignmentPairs",
-    function(object) .Defunct(msg=.GappedAlignmentPairs_warning_msg())
-)
-
-GappedAlignmentPairs <- function(...)
-    .Defunct(msg=.GappedAlignmentPairs_warning_msg())
-
-readGappedAlignmentPairs <- function(...)
-    .Defunct(msg=.GappedAlignmentPairs_warning_msg())
-
-setMethod("ngap", "GAlignmentPairs",
-    function(x)
-    {
-        .Deprecated("njunc")
-        njunc(x)
-    }
-)
-
