@@ -203,16 +203,16 @@ setReplaceMethod("seqinfo", "GAlignments",
     {
         if (!is(value, "Seqinfo"))
             stop("the supplied 'seqinfo' must be a Seqinfo object")
-        dangling_seqlevels <- GenomicRanges:::getDanglingSeqlevels(x,
+        dangling_seqlevels <- GenomeInfoDb:::getDanglingSeqlevels(x,
                                   new2old=new2old, force=force,
                                   seqlevels(value))
         if (length(dangling_seqlevels) != 0L)
             x <- x[!(seqnames(x) %in% dangling_seqlevels)]
         old_seqinfo <- seqinfo(x)
-        x@seqnames <- GenomicRanges:::makeNewSeqnames(x,
+        x@seqnames <- GenomeInfoDb:::makeNewSeqnames(x,
                                   new2old, seqlevels(value))
         x@seqinfo <- value
-        geom_has_changed <- GenomicRanges:::sequenceGeometryHasChanged(
+        geom_has_changed <- GenomeInfoDb:::sequenceGeometryHasChanged(
                                   seqinfo(x), old_seqinfo, new2old=new2old)
         if (any(geom_has_changed, na.rm=TRUE))
             validObject(x)
@@ -254,7 +254,7 @@ setReplaceMethod("seqinfo", "GAlignments",
 .valid.GAlignments.start <- function(x)
 {
     x_start <- start(x)
-    if (!is.integer(x_start) || !is.null(names(x_start)) || IRanges:::anyMissing(x_start))
+    if (!is.integer(x_start) || !is.null(names(x_start)) || S4Vectors:::anyMissing(x_start))
         return("'start(x)' must be an unnamed integer vector with no NAs")
     if (length(x_start) != length(cigar(x)))
         return("'start(x)' and 'cigar(x)' must have the same length")
@@ -530,23 +530,22 @@ setAs("GenomicRanges", "GAlignments",
 ### Subsetting.
 ###
 
-setMethod(IRanges:::extractROWS, "GAlignments",
+setMethod("extractROWS", "GAlignments",
     function(x, i)
     {
-        if (missing(i) || !is(i, "Ranges"))
-            i <- IRanges:::normalizeSingleBracketSubscript(i, x)
-        ans_names <- IRanges:::extractROWS(names(x), i)
-        ans_seqnames <- IRanges:::extractROWS(seqnames(x), i)
-        ans_start <- IRanges:::extractROWS(start(x), i)
-        ans_cigar <- IRanges:::extractROWS(cigar(x), i)
-        ans_strand <- IRanges:::extractROWS(strand(x), i)
-        ans_mcols <- IRanges:::extractROWS(mcols(x), i)
-        GenomicRanges:::clone(x, NAMES=ans_names,
+        i <- normalizeSingleBracketSubscript(i, x, as.NSBS=TRUE)
+        ans_NAMES <- extractROWS(x@NAMES, i)
+        ans_seqnames <- extractROWS(x@seqnames, i)
+        ans_start <- extractROWS(x@start, i)
+        ans_cigar <- extractROWS(x@cigar, i)
+        ans_strand <- extractROWS(x@strand, i)
+        ans_elementMetadata <- extractROWS(x@elementMetadata, i)
+        GenomicRanges:::clone(x, NAMES=ans_NAMES,
                                  seqnames=ans_seqnames,
                                  start=ans_start,
                                  cigar=ans_cigar,
                                  strand=ans_strand,
-                                 elementMetadata=ans_mcols)
+                                 elementMetadata=ans_elementMetadata)
     }
 )
 
@@ -561,7 +560,7 @@ setMethod(IRanges:::extractROWS, "GAlignments",
     nc <- ncol(mcols(x))
     ans <- cbind(seqnames=as.character(seqnames(x)),
                  strand=as.character(strand(x)),
-                 cigar=cigar(x),
+                 cigar=S4Vectors:::sketchStr(cigar(x), 23L),
                  qwidth=qwidth(x),
                  start=start(x),
                  end=end(x),
@@ -575,18 +574,18 @@ setMethod(IRanges:::extractROWS, "GAlignments",
 }
 
 showGAlignments <- function(x, margin="",
-                            with.classinfo=FALSE, print.seqlengths=FALSE)
+                            print.classinfo=FALSE, print.seqinfo=FALSE)
 {
     lx <- length(x)
     nc <- ncol(mcols(x))
-    cat(class(x), " with ",
+    cat(class(x), " object with ",
         lx, " ", ifelse(lx == 1L, "alignment", "alignments"),
         " and ",
         nc, " metadata ", ifelse(nc == 1L, "column", "columns"),
         ":\n", sep="")
-    out <- IRanges:::makePrettyMatrixForCompactPrinting(x,
+    out <- S4Vectors:::makePrettyMatrixForCompactPrinting(x,
                .makeNakedMatFromGAlignments)
-    if (with.classinfo) {
+    if (print.classinfo) {
         .COL2CLASS <- c(
             seqnames="Rle",
             strand="Rle",
@@ -598,7 +597,7 @@ showGAlignments <- function(x, margin="",
             njunc="integer"
         )
         classinfo <-
-            GenomicRanges:::makeClassinfoRowForCompactPrinting(x, .COL2CLASS)
+            S4Vectors:::makeClassinfoRowForCompactPrinting(x, .COL2CLASS)
         ## A sanity check, but this should never happen!
         stopifnot(identical(colnames(classinfo), colnames(out)))
         out <- rbind(classinfo, out)
@@ -609,16 +608,16 @@ showGAlignments <- function(x, margin="",
     ## limit that would typically be reached when 'showHeadLines' global
     ## option is set to Inf.
     print(out, quote=FALSE, right=TRUE, max=length(out))
-    if (print.seqlengths) {
-        cat(margin, "---\n", sep="")
-        GenomicRanges:::showSeqlengths(x, margin=margin)
+    if (print.seqinfo) {
+        cat(margin, "-------\n", sep="")
+        cat(margin, "seqinfo: ", summary(seqinfo(x)), "\n", sep="")
     }
 }
 
 setMethod("show", "GAlignments",
     function(object)
         showGAlignments(object, margin="  ",
-                        with.classinfo=TRUE, print.seqlengths=TRUE)
+                        print.classinfo=TRUE, print.seqinfo=TRUE)
 )
 
 
@@ -744,42 +743,3 @@ setMethod("c", "GAlignments",
     }
 )
 
-
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Old stuff (deprecated & defunct)
-###
-
-.GappedAlignments_warning_msg <- function()
-{
-    msg <- c("  The GappedAlignments class, the GappedAlignments()",
-             "constructor, and the readGappedAlignments() function, have been",
-             "renamed: GAlignments, GAlignments(), and readGAlignments(),",
-             "respectively. The old names are now defunct. Please use the ",
-             "new names instead.")
-    paste0(msg, collapse="\n  ")
-}
-
-setClass("GappedAlignments", contains="GAlignments")
-
-setValidity("GappedAlignments",
-    function(object) .Defunct(msg=.GappedAlignments_warning_msg())
-)
-
-setMethod("show", "GappedAlignments",
-    function(object) .Defunct(msg=.GappedAlignments_warning_msg())
-)
-
-GappedAlignments <- function(...)
-    .Defunct(msg=.GappedAlignments_warning_msg())
-
-readGappedAlignments <- function(...)
-    .Defunct(msg=.GappedAlignments_warning_msg())
-
-setMethod("ngap", "GAlignments",
-    function(x)
-    {
-        .Deprecated("njunc")
-        njunc(x)
-    }
-)
-
