@@ -24,7 +24,7 @@
 ###
 ###   (F) isProperPair(x[i1]) == isProperPair(y[i2])
 ###
-###   (G) isNotPrimaryRead(x[i1]) == isNotPrimaryRead(y[i2])
+###   (G) isSecondaryAlignment(x[i1]) == isSecondaryAlignment(y[i2])
 
 .checkMetadatacols <- function(arg, argname)
 {
@@ -93,7 +93,7 @@
     x2 <- match(x, x,
                 nomatch=.Machine$integer.max,
                 incomparables=NA_character_)
-    xo <- IRanges:::orderInteger(x2)
+    xo <- S4Vectors:::orderInteger(x2)
     ox2 <- Rle(x2[xo])
     group.sizes <- runLength(ox2)
     ngroup <- length(group.sizes)
@@ -155,8 +155,8 @@
         paste(idx, collapse=", "),
         ".\n!! Details:\n!! ", sep="")
     showGAlignments(x[idx], margin="!! ",
-                            with.classinfo=TRUE,
-                            print.seqlengths=FALSE)
+                            print.classinfo=TRUE,
+                            print.seqinfo=FALSE)
     cat("!! ==> won't assign a mate to them!\n")
 }
 
@@ -267,7 +267,7 @@ findMateAlignment <- function(x)
         query_hits <- subject_hits <- integer(0)
     } else {
         subject_hits0 <- m0[query_hits0]
-        subject_low2high <- IRanges:::makeLow2highFromHigh2low(
+        subject_low2high <- S4Vectors:::reverseSelfmatchMapping(
                                 high2low(subject))
         extra_hits <- subject_low2high[subject_hits0]
         query_nhits <- 1L + elementLengths(extra_hits)
@@ -278,9 +278,7 @@ findMateAlignment <- function(x)
         subject_hits[-idx0] <- unlist(extra_hits,
                                       recursive=FALSE, use.names=FALSE)
     }
-    new2("Hits", queryHits=query_hits, subjectHits=subject_hits,
-                 queryLength=length(query), subjectLength=length(subject),
-                 check=FALSE)
+    Hits(query_hits, subject_hits, length(query), length(subject))
 }
 
 ### Use to find self matches in 'x'. Twice faster than
@@ -291,7 +289,7 @@ findMateAlignment <- function(x)
     xo_and_GS <- .getCharacterOrderAndGroupSizes(x)
     xo <- xo_and_GS$xo
     GS <- xo_and_GS$group.sizes
-    ans <- IRanges:::makeAllGroupInnerHits(GS, hit.type=1L)
+    ans <- S4Vectors:::makeAllGroupInnerHits(GS, hit.type=1L)
     ans@queryHits <- xo[ans@queryHits]
     ans@subjectHits <- xo[ans@subjectHits]
     ans@queryLength <- ans@subjectLength <- length(x)
@@ -488,11 +486,3 @@ makeGAlignmentPairs <- function(x, use.names=FALSE, use.mcols=FALSE)
     GAlignmentPairs(ans_first, ans_last, ans_is_proper, names=ans_names)
 }
 
-
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Old stuff.
-###
-
-makeGappedAlignmentPairs <- function(...)
-    .Defunct("makeGAlignmentPairs")
-
