@@ -3,35 +3,6 @@
 ### -------------------------------------------------------------------------
 
 
-setGeneric("readGAlignmentsFromBam", signature="file",
-    function(file, index=file, ..., use.names=FALSE, param=NULL,
-                   with.which_label=FALSE)
-        standardGeneric("readGAlignmentsFromBam")
-)
-
-setGeneric("readGAlignmentPairsFromBam", signature="file",
-    function(file, index=file, use.names=FALSE, param=NULL,
-                   with.which_label=FALSE)
-        standardGeneric("readGAlignmentPairsFromBam")
-)
-
-setGeneric("readGAlignmentsListFromBam", signature="file",
-    function(file, index=file, ..., use.names=FALSE, param=ScanBamParam(),
-                   with.which_label=FALSE)
-        standardGeneric("readGAlignmentsListFromBam")
-)
-
-setGeneric("readGappedReadsFromBam", signature="file",
-    function(file, index=file, use.names=FALSE, param=NULL,
-                   with.which_label=FALSE)
-        standardGeneric("readGappedReadsFromBam")
-)
-
-
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Methods for BamFile objects.
-###
-
 ### A "flag filter" is represented as a 'flag' vector of length 2 with names
 ### keep0 and keep1. The .combineBamFlagFilters() function performs a logical
 ### AND between 2 "flag filters". It returns a "flag filter".
@@ -57,36 +28,9 @@ setGeneric("readGappedReadsFromBam", signature="file",
     param
 }
 
-.load_bamcols_from_bamfile <- function(bamfile, param, what0, ...,
-                                       with.which_label=FALSE)
-{
-    flag0 <- scanBamFlag(isUnmappedQuery=FALSE)
-    param <- .normargParam(param, flag0, what0)
-    res <- scanBam(bamfile, ..., param=param)
-    if (length(res) == 0L)  # should never happen
-        stop("scanBam() returned a list of length zero")
-    Rsamtools:::.load_bamcols_from_scanBam_res(res, param,
-                    with.which_label=with.which_label)
-}
-
-.load_seqlengths_from_bamfile <- function(file, seqlevels)
-{
-    seqlengths <- scanBamHeader(file)[["targets"]]
-    if (is.null(seqlengths))
-        return(NULL)
-    bad <- setdiff(seqlevels, names(seqlengths))
-    if (length(bad) == 0L)
-        return(seqlengths)
-    bad <- paste(bad, collapse="' '")
-    msg <- sprintf("'rname' lengths not in BamFile header; seqlengths not used\n  file: %s\n  missing rname(s): '%s'",
-                   path(file), bad)
-    warning(msg)
-    NULL
-}
-
 ### 'x' must be a GAlignments object.
 .bindExtraData <- function(x, use.names, param, bamcols,
-                           with.which_label=FALSE)
+                              with.which_label=FALSE)
 {
     if (use.names)
         names(x) <- bamcols$qname
@@ -106,57 +50,125 @@ setGeneric("readGappedReadsFromBam", signature="file",
     x
 }
 
-.matesFromBam <- function(file, use.names, param, what0, with.which_label)
+.load_bamcols_from_BamFile <- function(file, param, what0, 
+                                       with.which_label=FALSE)
 {
-    bamcols <- .load_bamcols_from_bamfile(file, param, what0,
-                                          with.which_label=with.which_label)
-    seqlengths <- .load_seqlengths_from_bamfile(file, levels(bamcols$rname))
-    gal <- GAlignments(seqnames=bamcols$rname, pos=bamcols$pos,
-                       cigar=bamcols$cigar, strand=bamcols$strand,
-                       seqlengths=seqlengths)
-    gal <- .bindExtraData(gal, use.names=FALSE, param, bamcols,
-                          with.which_label=with.which_label)
-    if (asMates(file)) {
-        f <- factor(bamcols$groupid)
-        gal <- unname(split(gal, f))
-        mcols(gal)$mate_status <- 
-            bamcols$mate_status[match(levels(f), bamcols$groupid)]
-    } else {
-        ## groupid=NULL when asMates=FALSE
-        gal <- unname(split(gal, seq_along(gal)))
-    }
-    if (use.names)
-        names(gal) <- unique(splitAsList(bamcols$qname, bamcols$groupid))
-
-    gal
+    flag0 <- scanBamFlag(isUnmappedQuery=FALSE)
+    param <- .normargParam(param, flag0, what0)
+    res <- scanBam(file, param=param)
+    if (length(res) == 0L)  # should never happen
+        stop("scanBam() returned a list of length zero")
+    Rsamtools:::.load_bamcols_from_scanBam_res(res, param,
+                    with.which_label=with.which_label)
 }
 
-setMethod("readGAlignmentsFromBam", "BamFile",
-    function(file, index=file, ..., use.names=FALSE, param=NULL,
+.load_seqlengths_from_BamFile <- function(file, seqlevels)
+{
+    seqlengths <- scanBamHeader(file)[["targets"]]
+    if (is.null(seqlengths))
+        return(NULL)
+    bad <- setdiff(seqlevels, names(seqlengths))
+    if (length(bad) == 0L)
+        return(seqlengths)
+    bad <- paste(bad, collapse="' '")
+    msg <- sprintf("'rname' lengths not in BamFile header; seqlengths not used\n  file: %s\n  missing rname(s): '%s'",
+                   path(file), bad)
+    warning(msg)
+    NULL
+}
+
+.open_BamFile <- function(file, index=file, asMates=FALSE, param=NULL)
+{
+    if ((missing(index) || identical(index, file))
+     && (is.null(param) || length(bamWhich(param)) == 0L))
+        index <- character(0)
+    open(BamFile(file, index=index, asMates=asMates), "rb")
+}
+
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### readGAlignments()
+###
+
+setGeneric("readGAlignments", signature="file",
+    function(file, index=file, use.names=FALSE, param=NULL,
+                   with.which_label=FALSE)
+        standardGeneric("readGAlignments")
+)
+
+.readGAlignments.BamFile <- function(file, index=file,
+                                     use.names=FALSE, param=NULL,
+                                     with.which_label=FALSE)
+{
+    if (!isTRUEorFALSE(use.names))
+        stop("'use.names' must be TRUE or FALSE")
+    if (is.null(param))
+        param <- ScanBamParam()
+    if (!asMates(file))
+        bamWhat(param) <- setdiff(bamWhat(param), 
+                                  c("groupid", "mate_status"))
+    what0 <- c("rname", "strand", "pos", "cigar")
+    if (use.names)
+        what0 <- c(what0, "qname")
+    bamcols <- .load_bamcols_from_BamFile(file, param, what0,
+                                          with.which_label=with.which_label)
+    seqlengths <- .load_seqlengths_from_BamFile(file,
+                                                levels(bamcols[["rname"]]))
+    ans <- GAlignments(seqnames=bamcols$rname, pos=bamcols$pos,
+                       cigar=bamcols$cigar, strand=bamcols$strand,
+                       seqlengths=seqlengths)
+    .bindExtraData(ans, use.names, param, bamcols,
+                        with.which_label=with.which_label)
+}
+
+setMethod("readGAlignments", "BamFile", .readGAlignments.BamFile)
+
+setMethod("readGAlignments", "character",
+    function(file, index=file, use.names=FALSE, param=NULL,
                    with.which_label=FALSE)
     {
-        if (!isTRUEorFALSE(use.names))
-            stop("'use.names' must be TRUE or FALSE")
-        if (is.null(param))
-            param <- ScanBamParam()
-        if (!asMates(file))
-            bamWhat(param) <- setdiff(bamWhat(param), 
-                                      c("groupid", "mate_status"))
-        what0 <- c("rname", "strand", "pos", "cigar")
-        if (use.names)
-            what0 <- c(what0, "qname")
-        bamcols <- .load_bamcols_from_bamfile(file, param, what0, ...,
-                                              with.which_label=with.which_label)
-        seqlengths <- .load_seqlengths_from_bamfile(file,
-                                                    levels(bamcols[["rname"]]))
-        ans <- GAlignments(seqnames=bamcols$rname, pos=bamcols$pos,
-                           cigar=bamcols$cigar, strand=bamcols$strand,
-                           seqlengths=seqlengths)
-        .bindExtraData(ans, use.names, param, bamcols,
-                       with.which_label=with.which_label)
+        bam <- .open_BamFile(file, index=index, param=param)
+        on.exit(close(bam))
+        readGAlignments(bam, character(0),
+                        use.names=use.names, param=param,
+                        with.which_label=with.which_label)
     }
 )
 
+setMethod("readGAlignments", "BamViews",
+    function(file, index=file, use.names=FALSE, param=NULL,
+                   with.which_label=FALSE)
+    {
+        if (missing(index))
+            index <- bamIndicies(file)
+        if (is.null(param)) {
+            param <- ScanBamParam(which=bamRanges(file))
+        } else if (!identical(bamRanges(file), bamWhich(param))) {
+            warning("'bamRanges(file)' and 'bamWhich(param)' differ; using 'bamRanges(file)'")
+            bamWhich(param) <- bamRanges(file)
+        }
+        fun <- function(i, bamViews, verbose)
+            readGAlignments(file=bamPaths(bamViews)[i],
+                            index=bamIndicies(bamViews)[i],
+                            use.names=use.names,
+                            param=param,
+                            with.which_label=with.which_label)
+        ### Rsamtools:::.BamViews_delegate requires the ShortRead package!
+        Rsamtools:::.BamViews_delegate("readGAlignments", file, fun)
+    }
+)
+
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### readGAlignmentPairs()
+###
+
+setGeneric("readGAlignmentPairs", signature="file",
+    function(file, index=file, use.names=FALSE, param=NULL,
+                   with.which_label=FALSE)
+        standardGeneric("readGAlignmentPairs")
+)
+
 ### 'use.mcols' can be TRUE, FALSE, or a character vector specifying the
 ### *inner* metadata columns to return, i.e., the metadata columns to set on
 ### the 2 halves of the returned GAlignmentPairs object.
@@ -196,8 +208,8 @@ setMethod("readGAlignmentsFromBam", "BamFile",
 
     ## Split and order the pairs by ascending start position of the first mate.
     idx1 <- which(as.logical(is_first_mate))
-    oo1 <- IRanges:::orderIntegerPairs(as.integer(gal@seqnames)[idx1],
-                                       gal@start[idx1])
+    oo1 <- S4Vectors:::orderIntegerPairs(as.integer(gal@seqnames)[idx1],
+                                         gal@start[idx1])
     idx1 <- idx1[oo1]
     idx2 <- which(as.logical(is_last_mate))[oo1]
     ans_first <- gal[idx1]
@@ -210,14 +222,14 @@ setMethod("readGAlignmentsFromBam", "BamFile",
     ans_names <- names(ans_first)
     names(ans_first) <- names(ans_last) <- NULL
 
-    ## Check isProperPair (0x2) and isNotPrimaryRead (0x100) flag bits.
+    ## Check isProperPair (0x2) and isSecondaryAlignment (0x100) flag bits.
     flag1 <- mcols(ans_first)[ , "flag"]
     flag2 <- mcols(ans_last)[ , "flag"]
     is_proper1 <- bamFlagAsBitMatrix(flag1, bitnames="isProperPair")
     is_proper2 <- bamFlagAsBitMatrix(flag2, bitnames="isProperPair")
     stopifnot(identical(is_proper1, is_proper2))
-    is_secondary1 <- bamFlagAsBitMatrix(flag1, bitnames="isNotPrimaryRead")
-    is_secondary2 <- bamFlagAsBitMatrix(flag2, bitnames="isNotPrimaryRead")
+    is_secondary1 <- bamFlagAsBitMatrix(flag1, bitnames="isSecondaryAlignment")
+    is_secondary2 <- bamFlagAsBitMatrix(flag2, bitnames="isSecondaryAlignment")
     stopifnot(identical(is_secondary1, is_secondary2))
 
     ## Drop discordant pairs. 
@@ -254,233 +266,183 @@ setMethod("readGAlignmentsFromBam", "BamFile",
                     names=ans_names)
 }
 
-setMethod("readGAlignmentPairsFromBam", "BamFile",
+.readGAlignmentPairs.BamFile <- function(file, index=file,
+                                         use.names=FALSE, param=NULL,
+                                         with.which_label=FALSE)
+{
+    if (!asMates(file)) {
+        asMates(file) <- TRUE
+        ## This is required because BamFile objects have a pass-by-address
+        ## semantic.
+        on.exit(asMates(file) <- FALSE)
+    }
+    if (is.null(param))
+        param <- ScanBamParam()
+    flag0 <- scanBamFlag(isPaired=TRUE, hasUnmappedMate=FALSE)
+    what0 <- c("flag", "groupid", "mate_status")
+    param2 <- .normargParam(param, flag0, what0)
+    gal <- readGAlignments(file, use.names=use.names, param=param2,
+                           with.which_label=with.which_label)
+    use.mcols <- c(bamWhat(param), bamTag(param))
+    if (with.which_label)
+        use.mcols <- c(use.mcols, "which_label")
+    .make_GAlignmentPairs_from_GAlignments(gal, use.mcols=use.mcols)
+}
+
+setMethod("readGAlignmentPairs", "BamFile", .readGAlignmentPairs.BamFile)
+
+setMethod("readGAlignmentPairs", "character",
     function(file, index=file, use.names=FALSE, param=NULL,
                    with.which_label=FALSE)
     {
-        if (!asMates(file)) {
-            asMates(file) <- TRUE
-            ## This is required because BamFile objects have a pass-by-address
-            ## semantic.
-            on.exit(asMates(file) <- FALSE)
-        }
-        if (is.null(param))
-            param <- ScanBamParam()
-        flag0 <- scanBamFlag(isPaired=TRUE, hasUnmappedMate=FALSE)
-        what0 <- c("flag", "groupid", "mate_status")
-        param2 <- .normargParam(param, flag0, what0)
-        gal <- readGAlignmentsFromBam(file, use.names=use.names,
-                                      param=param2,
-                                      with.which_label=with.which_label)
-        use.mcols <- c(bamWhat(param), bamTag(param))
-        if (with.which_label)
-            use.mcols <- c(use.mcols, "which_label")
-        .make_GAlignmentPairs_from_GAlignments(gal, use.mcols=use.mcols)
-    }
-)
-
-setMethod("readGAlignmentsListFromBam", "BamFile",
-    function(file, index=file, ..., use.names=FALSE, param=ScanBamParam(),
-                   with.which_label=FALSE)
-    {
-        if (!isTRUEorFALSE(use.names))
-            stop("'use.names' must be TRUE or FALSE")
-        if (!asMates(file))
-            bamWhat(param) <- setdiff(bamWhat(param), 
-                                      c("groupid", "mate_status"))
-        what0 <- c("rname", "strand", "pos", "cigar", "groupid", "mate_status")
-        if (use.names)
-            what0 <- c(what0, "qname")
-        .matesFromBam(file, use.names, param, what0, with.which_label)
-    }
-)
-
-setMethod("readGappedReadsFromBam", "BamFile",
-    function(file, index=file, use.names=FALSE, param=NULL,
-                   with.which_label=FALSE)
-    {
-        if (!isTRUEorFALSE(use.names))
-            stop("'use.names' must be TRUE or FALSE")
-        if (is.null(param))
-            param <- ScanBamParam()
-        if (!asMates(file))
-            bamWhat(param) <- setdiff(bamWhat(param), 
-                                      c("groupid", "mate_status"))
-        what0 <- c("rname", "strand", "pos", "cigar", "seq")
-        if (use.names)
-            what0 <- c(what0, "qname")
-        bamcols <- .load_bamcols_from_bamfile(file, param, what0,
-                                              with.which_label=with.which_label)
-        seqlengths <- .load_seqlengths_from_bamfile(file,
-                                                    levels(bamcols[["rname"]]))
-        ans <- GappedReads(seqnames=bamcols$rname, pos=bamcols$pos,
-                           cigar=bamcols$cigar, strand=bamcols$strand,
-                           qseq=bamcols$seq, seqlengths=seqlengths)
-        .bindExtraData(ans, use.names, param, bamcols,
-                       with.which_label=with.which_label)
+        bam <- .open_BamFile(file, index=index, asMates=TRUE, param=param)
+        on.exit(close(bam))
+        readGAlignmentPairs(bam, character(0),
+                            use.names=use.names, param=param,
+                            with.which_label=with.which_label)
     }
 )
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Methods for character vectors.
+### readGAlignmentsList()
 ###
 
-setMethod("readGAlignmentsFromBam", "character",
-    function(file, index=file, ..., use.names=FALSE, param=NULL,
+setGeneric("readGAlignmentsList", signature="file",
+    function(file, index=file, use.names=FALSE, param=ScanBamParam(),
+                   with.which_label=FALSE)
+        standardGeneric("readGAlignmentsList")
+)
+
+.matesFromBam <- function(file, use.names, param, what0, with.which_label)
+{
+    bamcols <- .load_bamcols_from_BamFile(file, param, what0,
+                                          with.which_label=with.which_label)
+    seqlengths <- .load_seqlengths_from_BamFile(file, levels(bamcols$rname))
+    gal <- GAlignments(seqnames=bamcols$rname, pos=bamcols$pos,
+                       cigar=bamcols$cigar, strand=bamcols$strand,
+                       seqlengths=seqlengths)
+    gal <- .bindExtraData(gal, use.names=FALSE, param, bamcols,
+                          with.which_label=with.which_label)
+    if (asMates(file)) {
+        f <- factor(bamcols$groupid)
+        gal <- unname(split(gal, f))
+        mcols(gal)$mate_status <- 
+            bamcols$mate_status[match(levels(f), bamcols$groupid)]
+    } else {
+        ## groupid=NULL when asMates=FALSE
+        gal <- unname(split(gal, seq_along(gal)))
+    }
+    if (use.names)
+        names(gal) <- unique(splitAsList(bamcols$qname, bamcols$groupid))
+    gal
+}
+
+.readGAlignmentsList.BamFile <- function(file, index=file,
+                                         use.names=FALSE, param=ScanBamParam(),
+                                         with.which_label=FALSE)
+{
+    if (!isTRUEorFALSE(use.names))
+        stop("'use.names' must be TRUE or FALSE")
+    if (!asMates(file))
+        bamWhat(param) <- setdiff(bamWhat(param), 
+                                  c("groupid", "mate_status"))
+    what0 <- c("rname", "strand", "pos", "cigar", "groupid", "mate_status")
+    if (use.names)
+        what0 <- c(what0, "qname")
+    .matesFromBam(file, use.names, param, what0, with.which_label)
+}
+
+setMethod("readGAlignmentsList", "BamFile", .readGAlignmentsList.BamFile)
+
+setMethod("readGAlignmentsList", "character",
+    function(file, index=file, use.names=FALSE, param=ScanBamParam(),
                    with.which_label=FALSE)
     {
-        if (missing(index) && (is.null(param) || 0L == length(bamWhich(param))))
-            index <- character(0)
-        bam <- open(BamFile(file, index), "rb")
+        bam <- .open_BamFile(file, index=index, asMates=TRUE, param=param)
         on.exit(close(bam))
-        readGAlignmentsFromBam(bam, character(), ..., use.names=use.names,
-                               param=param,
-                               with.which_label=with.which_label)
+        readGAlignmentsList(bam, character(0),
+                            use.names=use.names, param=param,
+                            with.which_label=with.which_label)
     }
 )
 
-setMethod("readGappedReadsFromBam", "character",
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### readGappedReads()
+###
+
+setGeneric("readGappedReads", signature="file",
+    function(file, index=file, use.names=FALSE, param=NULL,
+                   with.which_label=FALSE)
+        standardGeneric("readGappedReads")
+)
+
+.readGappedReads.BamFile <- function(file, index=file,
+                                     use.names=FALSE, param=NULL,
+                                     with.which_label=FALSE)
+{
+    if (!isTRUEorFALSE(use.names))
+        stop("'use.names' must be TRUE or FALSE")
+    if (is.null(param))
+        param <- ScanBamParam()
+    if (!asMates(file))
+        bamWhat(param) <- setdiff(bamWhat(param), 
+                                  c("groupid", "mate_status"))
+    what0 <- c("rname", "strand", "pos", "cigar", "seq")
+    if (use.names)
+        what0 <- c(what0, "qname")
+    bamcols <- .load_bamcols_from_BamFile(file, param, what0,
+                                          with.which_label=with.which_label)
+    seqlengths <- .load_seqlengths_from_BamFile(file,
+                                                levels(bamcols[["rname"]]))
+    ans <- GappedReads(seqnames=bamcols$rname, pos=bamcols$pos,
+                       cigar=bamcols$cigar, strand=bamcols$strand,
+                       qseq=bamcols$seq, seqlengths=seqlengths)
+    .bindExtraData(ans, use.names, param, bamcols,
+                   with.which_label=with.which_label)
+}
+
+setMethod("readGappedReads", "BamFile", .readGappedReads.BamFile)
+
+setMethod("readGappedReads", "character",
     function(file, index=file, use.names=FALSE, param=NULL,
                    with.which_label=FALSE)
     {
-        if (missing(index) && (is.null(param) || 0L == length(bamWhich(param))))
-            index <- character(0)
-        bam <- open(BamFile(file, index), "rb")
+        bam <- .open_BamFile(file, index=index, param=param)
         on.exit(close(bam))
-        readGappedReadsFromBam(bam, character(), use.names=use.names,
-                               param=param,
-                               with.which_label=with.which_label)
-    }
-)
-
-setMethod("readGAlignmentPairsFromBam", "character",
-    function(file, index=file, use.names=FALSE, param=NULL,
-                   with.which_label=FALSE)
-    {
-        if (missing(index) && (is.null(param) || 0L == length(bamWhich(param))))
-            index <- character(0)
-        bam <- open(BamFile(file, index, asMates=TRUE), "rb")
-        on.exit(close(bam))
-        readGAlignmentPairsFromBam(bam, character(), use.names=use.names,
-                                   param=param,
-                                   with.which_label=with.which_label)
-    }
-)
-
-setMethod("readGAlignmentsListFromBam", "character",
-    function(file, index=file, ..., use.names=FALSE,
-                   param=ScanBamParam(), with.which_label=FALSE)
-    {
-        if (missing(index) && (is.null(param) || 0L == length(bamWhich(param))))
-            index <- character(0)
-        bam <- open(BamFile(file, index, asMates=TRUE), "rb")
-        on.exit(close(bam))
-        readGAlignmentsListFromBam(bam, character(), use.names=use.names,
-                                   param=param,
-                                   with.which_label=with.which_label)
+        readGappedReads(bam, character(0),
+                        use.names=use.names, param=param,
+                        with.which_label=with.which_label)
     }
 )
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Methods for BamViews objects.
+### Old stuff (deprecated & defunct)
 ###
 
-setMethod("readGAlignmentsFromBam", "BamViews",
-    function(file, index=file, ..., use.names=FALSE, param=NULL,
-                   with.which_label=FALSE)
-    {
-        if (missing(index))
-            index <- bamIndicies(file)
-        if (is.null(param)) {
-            param <- ScanBamParam(which=bamRanges(file))
-        } else if (!identical(bamRanges(file), bamWhich(param))) {
-            warning("'bamRanges(file)' and 'bamWhich(param)' differ; using 'bamRanges(file)'")
-            bamWhich(param) <- bamRanges(file)
-        }
-        fun <- function(i, bamViews, verbose)
-            readGAlignmentsFromBam(file=bamPaths(bamViews)[i],
-                                   index=bamIndicies(bamViews)[i],
-                                   use.names=use.names,
-                                   param=param,
-                                   with.which_label=with.which_label)
-        Rsamtools:::.BamViews_delegate("readGAlignmentsFromBam", file, fun)
-    }
-)
-
-
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Front-ends
-###
-
-readGAlignments <- function(file, format="BAM", use.names=FALSE, ...)
+readGAlignmentsFromBam <- function(...)
 {
-    if (!isSingleString(format))
-        stop("'format' must be a single string")
-    if (!isTRUEorFALSE(use.names))
-        stop("'use.names' must be TRUE or FALSE")
-    if (format == "BAM") {
-        ans <- readGAlignmentsFromBam(file=file, use.names=use.names, ...)
-        return(ans)
-    }
-    stop("only BAM format is supported at the moment")
+    .Deprecated("readGAlignments")
+    readGAlignments(...)
 }
 
-readGAlignmentPairs <- function(file, format="BAM", use.names=FALSE, ...)
+readGAlignmentPairsFromBam <- function(...)
 {
-    if (!isSingleString(format))
-        stop("'format' must be a single string")
-    if (!isTRUEorFALSE(use.names))
-        stop("'use.names' must be TRUE or FALSE")
-    if (format == "BAM") {
-        ans <- readGAlignmentPairsFromBam(file=file, use.names=use.names, ...)
-        return(ans)
-    }
-    stop("only BAM format is supported at the moment")
+    .Deprecated("readGAlignmentPairs")
+    readGAlignmentPairs(...)
 }
 
-readGAlignmentsList <- function(file, format="BAM", use.names=FALSE, ...)
+readGAlignmentsListFromBam <- function(...)
 {
-    if (!isSingleString(format))
-        stop("'format' must be a single string")
-    if (!isTRUEorFALSE(use.names))
-        stop("'use.names' must be TRUE or FALSE")
-    if (format == "BAM") {
-        ans <- readGAlignmentsListFromBam(file=file, use.names=use.names, ...)
-        return(ans)
-    }
-    stop("only BAM format is supported at the moment")
+    .Deprecated("readGAlignmentsList")
+    readGAlignmentsList(...)
 }
 
-readGappedReads <- function(file, format="BAM", use.names=FALSE, ...)
+readGappedReadsFromBam <- function(...)
 {
-    if (!isSingleString(file))
-        stop("'file' must be a single string")
-    if (!isSingleString(format))
-        stop("'format' must be a single string")
-    if (!isTRUEorFALSE(use.names))
-        stop("'use.names' must be TRUE or FALSE")
-    if (format == "BAM") {
-        ans <- readGappedReadsFromBam(file=file, use.names=use.names, ...)
-        return(ans)
-    }
-    stop("only BAM format is supported at the moment")
+    .Deprecated("readGappedReads")
+    readGappedReads(...)
 }
 
-
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Old stuff.
-###
-
-readBamGappedAlignments <- function(...)
-    .Defunct("readGAlignmentsFromBam")
-
-readBamGappedReads <- function(...)
-    .Defunct("readGappedReadsFromBam")
-
-readBamGappedAlignmentPairs <- function(...)
-    .Defunct("readGAlignmentPairsFromBam")
-
-readBamGAlignmentsList <- function(...)
-    .Defunct("readGAlignmentsListFromBam")
