@@ -3,6 +3,15 @@
 
 /* cigar_utils.c */
 
+const char *_get_cigar_parsing_error();
+
+int _next_cigar_OP(
+	const char *cigar_string,
+	int offset,
+	char *OP,
+	int *OPL
+);
+
 SEXP valid_cigar(
 	SEXP cigar,
 	SEXP ans_type
@@ -50,6 +59,23 @@ SEXP cigar_qnarrow(
 	SEXP right_qwidth
 );
 
+
+/* coordinate_mapping_methods.c */
+
+SEXP map_query_locs_to_ref_locs(
+	SEXP start,
+	SEXP end,
+	SEXP cigar,
+	SEXP pos
+);
+
+SEXP map_ref_locs_to_query_locs(
+	SEXP start,
+	SEXP end,
+	SEXP cigar,
+	SEXP pos
+);
+
 SEXP ref_locs_to_query_locs(
 	SEXP ref_locs,
 	SEXP cigar,
