@@ -1,5 +1,6 @@
 #include "GenomicAlignments.h"
 #include "IRanges_interface.h"
+#include "S4Vectors_interface.h"
 
 #include <ctype.h> /* for isdigit() */
 
@@ -15,11 +16,17 @@
 
 static char errmsg_buf[200];
 
+const char *_get_cigar_parsing_error()
+{
+	return errmsg_buf;
+}
+
 /* Return the number of chars that was read, or 0 if there is no more char
-   to read (i.e. cigar_string[offset] is '\0'), or -1 in case of a parse error.
+   to read (i.e. cigar_string[offset] is '\0'), or -1 in case of a parse error
+   (in which case _get_cigar_parsing_error() can be used to get a pointer to
+   the error message).
    Zero-length operations are ignored. */
-static int next_cigar_OP(const char *cigar_string, int offset,
-		char *OP, int *OPL)
+int _next_cigar_OP(const char *cigar_string, int offset, char *OP, int *OPL)
 {
 	char c;
 	int offset0, opl;
@@ -156,24 +163,24 @@ static int is_visible_in_space(char OP, int space)
 
 static void drop_or_append_or_merge_range(int start, int width,
 		int drop_empty_range, int merge_range, int nelt0,
-		RangeAE *range_buf, const char *OP, CharAEAE *OP_buf)
+		IntPairAE *range_buf, const char *OP, CharAEAE *OP_buf)
 {
 	int buf_nelt, buf_nelt_minus_1, prev_end_plus_1;
 	CharAE OP_buf_new_elt, *OP_buf_prev_elt;
 
 	if (drop_empty_range && width == 0)  /* Drop. */
 		return;
-	buf_nelt = RangeAE_get_nelt(range_buf);
+	buf_nelt = IntPairAE_get_nelt(range_buf);
 	if (merge_range && buf_nelt > nelt0) {
 		/* The incoming range should never overlap with the previous
 		   incoming range i.e. 'start' should always be > the end of
 		   the previous incoming range. */
 		buf_nelt_minus_1 = buf_nelt - 1;
-		prev_end_plus_1 = range_buf->start.elts[buf_nelt_minus_1] +
-				  range_buf->width.elts[buf_nelt_minus_1];
+		prev_end_plus_1 = range_buf->a.elts[buf_nelt_minus_1] +
+				  range_buf->b.elts[buf_nelt_minus_1];
 		if (start == prev_end_plus_1) {
 			/* Merge. */
-			range_buf->width.elts[buf_nelt_minus_1] += width;
+			range_buf->b.elts[buf_nelt_minus_1] += width;
 			if (OP_buf != NULL) {
 				OP_buf_prev_elt = OP_buf->elts +
 						  buf_nelt_minus_1;
@@ -184,7 +191,7 @@ static void drop_or_append_or_merge_range(int start, int width,
 		}
 	}
 	/* Append. */
-	RangeAE_insert_at(range_buf, buf_nelt, start, width);
+	IntPairAE_insert_at(range_buf, buf_nelt, start, width);
 	if (OP_buf != NULL) {
 		OP_buf_new_elt = new_CharAE(1);
 		CharAE_insert_at(&OP_buf_new_elt, 0, *OP);
@@ -197,18 +204,18 @@ static void drop_or_append_or_merge_range(int start, int width,
 static const char *parse_cigar_ranges(const char *cigar_string,
 		int space, int pos,
 		int drop_empty_ranges, int reduce_ranges,
-		RangeAE *range_buf, CharAEAE *OP_buf)
+		IntPairAE *range_buf, CharAEAE *OP_buf)
 {
 	int buf_nelt0, cigar_offset, n, OPL /* Operation Length */,
 	    start, width;
 	char OP /* Operation */;
 
-	buf_nelt0 = RangeAE_get_nelt(range_buf);
+	buf_nelt0 = IntPairAE_get_nelt(range_buf);
 	cigar_offset = 0;
 	start = pos;
-	while ((n = next_cigar_OP(cigar_string, cigar_offset, &OP, &OPL))) {
+	while ((n = _next_cigar_OP(cigar_string, cigar_offset, &OP, &OPL))) {
 		if (n == -1)
-			return errmsg_buf;
+			return _get_cigar_parsing_error();
 		width = is_visible_in_space(OP, space) ? OPL : 0;
 		if (is_in_ops(OP))
 			drop_or_append_or_merge_range(start, width,
@@ -228,9 +235,9 @@ static const char *parse_cigar_width(const char *cigar_string, int space,
 	char OP /* Operation */;
 
 	*width = cigar_offset = 0;
-	while ((n = next_cigar_OP(cigar_string, cigar_offset, &OP, &OPL))) {
+	while ((n = _next_cigar_OP(cigar_string, cigar_offset, &OP, &OPL))) {
 		if (n == -1)
-			return errmsg_buf;
+			return _get_cigar_parsing_error();
 		if (is_visible_in_space(OP, space))
 			*width += OPL;
 		cigar_offset += n;
@@ -306,9 +313,9 @@ static const char *split_cigar_string(const char *cigar_string,
 	char OP /* Operation */;
 
 	offset = 0;
-	while ((n = next_cigar_OP(cigar_string, offset, &OP, &OPL))) {
+	while ((n = _next_cigar_OP(cigar_string, offset, &OP, &OPL))) {
 		if (n == -1)
-			return errmsg_buf;
+			return _get_cigar_parsing_error();
 		if (is_in_ops(OP)) {
 			if (OPbuf != NULL)
 				CharAE_insert_at(OPbuf,
@@ -437,9 +444,9 @@ static const char *cigar_string_op_table(SEXP cigar_string, const char *allOPs,
 		return "CIGAR string is empty";
 	cig0 = CHAR(cigar_string);
 	offset = 0;
-	while ((n = next_cigar_OP(cig0, offset, &OP, &OPL))) {
+	while ((n = _next_cigar_OP(cig0, offset, &OP, &OPL))) {
 		if (n == -1)
-			return errmsg_buf;
+			return _get_cigar_parsing_error();
 		tmp = strchr(allOPs, (int) OP);
 		if (tmp == NULL) {
 			snprintf(errmsg_buf, sizeof(errmsg_buf),
@@ -506,24 +513,25 @@ SEXP cigar_op_table(SEXP cigar)
  * cigar_ranges()
  */
 
-static SEXP make_list_of_IRanges(const RangeAEAE *range_buf, SEXP names)
+static SEXP make_list_of_IRanges(const IntPairAEAE *range_buf, SEXP names)
 {
 	SEXP ans, ans_names;
 
-	PROTECT(ans = new_list_of_IRanges_from_RangeAEAE("IRanges", range_buf));
+	PROTECT(ans = new_list_of_IRanges_from_IntPairAEAE("IRanges",
+							   range_buf));
 	PROTECT(ans_names = duplicate(names));
 	SET_NAMES(ans, ans_names);
 	UNPROTECT(2);
 	return ans;
 }
 
-static SEXP make_CompressedIRangesList(const RangeAE *range_buf,
+static SEXP make_CompressedIRangesList(const IntPairAE *range_buf,
 		const CharAEAE *OP_buf, SEXP breakpoints)
 {
 	SEXP ans, ans_unlistData, ans_unlistData_names, ans_partitioning;
 
 	PROTECT(ans_unlistData =
-			new_IRanges_from_RangeAE("IRanges", range_buf));
+			new_IRanges_from_IntPairAE("IRanges", range_buf));
 	if (OP_buf != NULL) {
 		PROTECT(ans_unlistData_names =
 				new_CHARACTER_from_CharAEAE(OP_buf));
@@ -579,8 +587,8 @@ SEXP cigar_ranges(SEXP cigar, SEXP flag, SEXP space, SEXP pos, SEXP f,
 	SEXP ans, ans_breakpoints, f_levels, cigar_elt;
 	int cigar_len, space0, pos_len, f_is_NULL, ans_len, *breakpoint,
 	    drop_empty_ranges0, reduce_ranges0, with_ops0, i;
-	RangeAE range_buf1, *range_buf_p;
-	RangeAEAE range_buf2;
+	IntPairAE range_buf1, *range_buf_p;
+	IntPairAEAE range_buf2;
 	CharAEAE OP_buf, *OP_buf_p;
 	const int *flag_elt, *pos_elt, *f_elt;
 	const char *cigar_string, *errmsg;
@@ -596,14 +604,14 @@ SEXP cigar_ranges(SEXP cigar, SEXP flag, SEXP space, SEXP pos, SEXP f,
 	if (f_is_NULL) {
 		ans_len = cigar_len;
 		/* We will typically generate at least 'cigar_len' ranges. */
-		range_buf1 = new_RangeAE(ans_len, 0);
+		range_buf1 = new_IntPairAE(ans_len, 0);
 		range_buf_p = &range_buf1;
 		PROTECT(ans_breakpoints = NEW_INTEGER(ans_len));
 		breakpoint = INTEGER(ans_breakpoints);
 	} else {
 		f_levels = GET_LEVELS(f);
 		ans_len = LENGTH(f_levels);
-		range_buf2 = new_RangeAEAE(ans_len, ans_len);
+		range_buf2 = new_IntPairAEAE(ans_len, ans_len);
 		f_elt = INTEGER(f);
 	}
 	drop_empty_ranges0 = LOGICAL(drop_empty_ranges)[0];
@@ -665,7 +673,7 @@ for_tail:
 		if (pos_len != 1)
 			pos_elt++;
 		if (f_is_NULL)
-			*(breakpoint++) = RangeAE_get_nelt(range_buf_p);
+			*(breakpoint++) = IntPairAE_get_nelt(range_buf_p);
 		else
 			f_elt++;
 	}
@@ -749,9 +757,9 @@ static const char *Lnarrow_cigar_string(SEXP cigar_string,
 		return "CIGAR string is empty";
 	cig0 = CHAR(cigar_string);
 	*rshift = offset = 0;
-	while ((n = next_cigar_OP(cig0, offset, &OP, &OPL))) {
+	while ((n = _next_cigar_OP(cig0, offset, &OP, &OPL))) {
 		if (n == -1)
-			return errmsg_buf;
+			return _get_cigar_parsing_error();
 		switch (OP) {
 		/* Alignment match (can be a sequence match or mismatch) */
 		    case 'M': case '=': case 'X':
@@ -804,7 +812,7 @@ static const char *Rnarrow_cigar_string(SEXP cigar_string,
 	offset = LENGTH(cigar_string);
 	while ((n = prev_cigar_OP(cig0, offset, &OP, &OPL))) {
 		if (n == -1)
-			return errmsg_buf;
+			return _get_cigar_parsing_error();
 		offset -= n;
 		switch (OP) {
 		/* Alignment match (can be a sequence match or mismatch) */
@@ -868,7 +876,7 @@ static const char *narrow_cigar_string(SEXP cigar_string,
 	buf_offset = 0;
 	cig0 = CHAR(cigar_string);
 	for (offset = Loffset; offset <= Roffset; offset += n) {
-		n = next_cigar_OP(cig0, offset, &OP, &OPL);
+		n = _next_cigar_OP(cig0, offset, &OP, &OPL);
 		if (offset == Loffset)
 			OPL -= Lwidth;
 		if (offset == Roffset)
@@ -940,9 +948,9 @@ static const char *Lqnarrow_cigar_string(SEXP cigar_string,
 		return "CIGAR string is empty";
 	cig0 = CHAR(cigar_string);
 	*rshift = offset = 0;
-	while ((n = next_cigar_OP(cig0, offset, &OP, &OPL))) {
+	while ((n = _next_cigar_OP(cig0, offset, &OP, &OPL))) {
 		if (n == -1)
-			return errmsg_buf;
+			return _get_cigar_parsing_error();
 		switch (OP) {
 		/* Alignment match (can be a sequence match or mismatch) */
 		    case 'M': case '=': case 'X':
@@ -996,7 +1004,7 @@ static const char *Rqnarrow_cigar_string(SEXP cigar_string,
 	offset = LENGTH(cigar_string);
 	while ((n = prev_cigar_OP(cig0, offset, &OP, &OPL))) {
 		if (n == -1)
-			return errmsg_buf;
+			return _get_cigar_parsing_error();
 		offset -= n;
 		switch (OP) {
 		/* M, =, X, I, S, H */
@@ -1052,7 +1060,7 @@ static const char *qnarrow_cigar_string(SEXP cigar_string,
 	buf_offset = 0;
 	cig0 = CHAR(cigar_string);
 	for (offset = Loffset; offset <= Roffset; offset += n) {
-		n = next_cigar_OP(cig0, offset, &OP, &OPL);
+		n = _next_cigar_OP(cig0, offset, &OP, &OPL);
 		if (offset == Loffset)
 			OPL -= Lqwidth;
 		if (offset == Roffset)
@@ -1110,165 +1118,3 @@ SEXP cigar_qnarrow(SEXP cigar, SEXP left_qwidth, SEXP right_qwidth)
 	UNPROTECT(3);
 	return ans;
 }
-
-
-/****************************************************************************
- * --- .Call ENTRY POINT ---
- * Args:
- *   ref_locs: global positions in the reference that we will map
- *   cigar: character string containing the extended CIGAR;
- *   pos: reference position at which the query alignment begins
- *        (after clip)
- *   narrow_left: whether to narrow to the left (or right) side of a gap
- * Returns the local query positions. This assumes that the reference
- * positions actually occur in the read alignment region, outside of
- * any deletions or insertions. 
- */
-SEXP ref_locs_to_query_locs(SEXP ref_locs, SEXP cigar, SEXP pos,
-                            SEXP narrow_left)
-{
-  int nlocs, i;
-  SEXP query_locs;
-  Rboolean _narrow_left = asLogical(narrow_left);
-  
-  nlocs = LENGTH(ref_locs);
-  PROTECT(query_locs = allocVector(INTSXP, nlocs));
-  
-  for (i = 0; i < nlocs; i++) {
-    int query_loc = INTEGER(ref_locs)[i] - INTEGER(pos)[i] + 1;
-    int n, offset = 0, OPL, query_consumed = 0;
-    char OP;
-    const char *cig0 = CHAR(STRING_ELT(cigar, i));
-    while (query_consumed < query_loc &&
-           (n = next_cigar_OP(cig0, offset, &OP, &OPL)))
-    {
-      switch (OP) {
-        /* Alignment match (can be a sequence match or mismatch) */
-      case 'M': case '=': case 'X':
-        query_consumed += OPL;
-        break;
-        /* Insertion to the reference */
-      case 'I':
-        /* Soft clip on the read */
-      case 'S':
-        query_loc += OPL;
-        query_consumed += OPL;
-        break;
-        /* Deletion from the reference */
-      case 'D':
-      case 'N': /* Skipped region from reference; narrow to query */
-        {
-          Rboolean query_loc_past_gap = query_loc - query_consumed > OPL;
-          if (query_loc_past_gap) {
-            query_loc -= OPL;
-          } else {
-            if (_narrow_left) {
-              query_loc = query_consumed;
-            } else {
-              query_loc = query_consumed + 1;
-            }
-          }
-        }
-        break;
-       /* Hard clip on the read */
-      case 'H':
-        break;
-        /* Silent deletion from the padded reference */
-      case 'P':
-        break;
-      default:
-        break;
-      }
-      offset += n;
-    }
-    if (n == 0)
-      error("hit end of cigar string %d: %s", i + 1, cig0);
-    INTEGER(query_locs)[i] = query_loc;
-  }
-
-  UNPROTECT(1);
-  return query_locs;
-}
-
-
-/****************************************************************************
- * --- .Call ENTRY POINT ---
- * Args:
- *   query_locs: local positions in the read that we will map
- *   cigar: character string containing the extended CIGAR;
- *   pos: reference position at which the query alignment begins
- *        (after clip)
- *   narrow_left: whether to narrow to the left (or right) side of a gap
- * Returns the local query positions. This assumes that the reference
- * positions actually occur in the read alignment region, outside of
- * any deletions or insertions. 
- */
-SEXP query_locs_to_ref_locs(SEXP query_locs, SEXP cigar, SEXP pos,
-                            SEXP narrow_left)
-{
-  int nlocs, i;
-  SEXP ref_locs;
-  Rboolean _narrow_left = asLogical(narrow_left);
-  
-  nlocs = LENGTH(query_locs);
-  PROTECT(ref_locs = allocVector(INTSXP, nlocs));
-  
-  for (i = 0; i < nlocs; i++) {
-    int query_loc_i = INTEGER(query_locs)[i];
-    int ref_loc = query_loc_i + INTEGER(pos)[i] - 1;
-    int n, offset = 0, OPL, query_consumed = 0;
-    char OP;
-    const char *cig0 = CHAR(STRING_ELT(cigar, i));
-    while (query_consumed < query_loc_i &&
-           (n = next_cigar_OP(cig0, offset, &OP, &OPL)))
-      {
-        switch (OP) {
-          /* Alignment match (can be a sequence match or mismatch) */
-        case 'M': case '=': case 'X':
-          query_consumed += OPL;
-          break;
-          /* Insertion to the reference */
-        case 'I': {
-          /* Soft clip on the read */
-          int width_from_insertion_start = query_loc_i - query_consumed;
-          Rboolean query_loc_past_insertion = width_from_insertion_start > OPL;
-          if (query_loc_past_insertion) {
-            ref_loc -= OPL;
-          } else {
-            ref_loc -= width_from_insertion_start;
-            if (!_narrow_left) {
-              ref_loc += 1;
-            }
-          }
-          query_consumed += OPL;
-          break;
-        }
-        case 'S':
-          query_consumed += OPL;
-          ref_loc -= OPL;
-          break;
-          /* Deletion from the reference */
-        case 'D':
-        case 'N': /* Skipped region from reference; narrow to query */
-          ref_loc += OPL;
-          break;
-          /* Hard clip on the read */
-        case 'H':
-          break;
-          /* Silent deletion from the padded reference */
-        case 'P':
-          break;
-        default:
-          break;
-        }
-        offset += n;
-      }
-    if (n == 0)
-      error("hit end of cigar string %d: %s", i + 1, cig0);
-    INTEGER(ref_locs)[i] = ref_loc;
-  }
-
-  UNPROTECT(1);
-  return ref_locs;
-}
-
